﻿using System.Collections.Generic;
using System.Linq;
using Windows.Foundation;
using Windows.UI.Input;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Shapes;

namespace GetIntermediatePointsReversed
{
    public sealed partial class MainPage : Page
    {
        Dictionary<uint, Polyline> pointerDictionary = new Dictionary<uint, Polyline>();

        public MainPage()
        {
            this.InitializeComponent();
        }

        protected override void OnPointerPressed(PointerRoutedEventArgs args)
        {
            // Get information from event arguments
            uint id = args.Pointer.PointerId;
            Point point = args.GetCurrentPoint(this).Position;

            // Create Polyline
            Polyline polyline = new Polyline
            {
                Stroke = this.Resources["ApplicationForegroundThemeBrush"] as Brush,
                StrokeThickness = 4
            };
            polyline.Points.Add(point);

            // Add to Grid and dictionary
            contentGrid.Children.Add(polyline);
            pointerDictionary.Add(id, polyline);
            base.OnPointerPressed(args);
        }

        protected override void OnPointerMoved(PointerRoutedEventArgs args)
        {
            // Get information from event arguments
            uint id = args.Pointer.PointerId;

            // If ID is in dictionary, add the points to the Polyline
            if (pointerDictionary.ContainsKey(id))
            {
                foreach (PointerPoint pointerPoint in args.GetIntermediatePoints(this).Reverse())
                {
                    pointerDictionary[id].Points.Add(pointerPoint.Position);
                }
            }
            base.OnPointerMoved(args);
        }

        protected override void OnPointerReleased(PointerRoutedEventArgs args)
        {
            // Get information from event arguments
            uint id = args.Pointer.PointerId;

            // If ID is in dictionary, remove it
            if (pointerDictionary.ContainsKey(id))
                pointerDictionary.Remove(id);

            base.OnPointerReleased(args);
        }
    }
}
